@@ -1,19 +1,20 @@
 from __future__ import absolute_import, unicode_literals
 
 from django.forms import Media, widgets
-from django.templatetags.static import static
 from wagtail.utils.widgets import WidgetWithScript
 
+from .settings import config
+
 
 class CKEditor(WidgetWithScript, widgets.Textarea):
     def render_js_init(self, id_, name, value):
-        return f"initCKEditor({id_})"
+        return (
+            "ClassicEditor.create"
+            "(document.getElementById('{id}', {config}))".format(
+                id=id_, config=config
+            )
+        )
 
     @property
     def media(self):
-        return Media(
-            js=[
-                static("wagtail_ckeditor/ckeditor.js"),
-                static("wagtail_ckeditor/initEditor.js"),
-            ]
-        )
+        return Media(js=["wagtail_ckeditor/ckeditor.js"])
